"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StellatePlugin = void 0;
const tslib_1 = require("tslib");
const common_1 = require("@nestjs/common");
const core_1 = require("@nestjs/core");
const core_2 = require("@vendure/core");
const constants_1 = require("./constants");
const stellate_service_1 = require("./service/stellate.service");
const api_extensions_1 = require("./api/api-extensions");
const search_response_resolver_1 = require("./api/search-response.resolver");
const operators_1 = require("rxjs/operators");
const StellateOptionsProvider = {
    provide: constants_1.STELLATE_PLUGIN_OPTIONS,
    useFactory: () => StellatePlugin.options,
};
/**
 * @description
 * A plugin to integrate Stellate's GraphQL caching service with your Vendure server.
 * The main purpose of this plugin is to ensure that cached data gets correctly purged in
 * response to events inside Vendure. For example, changes to a Product's description should
 * purge any associated record for that Product in Stellate's cache.
 */
let StellatePlugin = class StellatePlugin {
    constructor(options, eventBus, stellateService, moduleRef) {
        this.options = options;
        this.eventBus = eventBus;
        this.stellateService = stellateService;
        this.moduleRef = moduleRef;
    }
    static init(options) {
        this.options = options;
        return this;
    }
    onApplicationBootstrap() {
        var _a, _b, _c;
        const injector = new core_2.Injector(this.moduleRef);
        for (const purgeRule of (_a = this.options.purgeRules) !== null && _a !== void 0 ? _a : []) {
            const source$ = this.eventBus.ofType(purgeRule.eventType);
            source$
                .pipe((0, operators_1.buffer)(source$.pipe((0, operators_1.debounceTime)((_c = (_b = purgeRule.bufferTimeMs) !== null && _b !== void 0 ? _b : this.options.defaultBufferTimeMs) !== null && _c !== void 0 ? _c : 2000))))
                .subscribe((events) => purgeRule.handle({ events, injector, stellateService: this.stellateService }));
        }
    }
};
StellatePlugin = (0, tslib_1.__decorate)([
    (0, core_2.VendurePlugin)({
        imports: [core_2.PluginCommonModule],
        providers: [StellateOptionsProvider, stellate_service_1.StellateService],
        shopApiExtensions: {
            schema: api_extensions_1.shopApiExtensions,
            resolvers: [search_response_resolver_1.SearchResponseFieldResolver],
        },
        configuration: (config) => {
            return config;
        },
    }),
    (0, tslib_1.__param)(0, (0, common_1.Inject)(constants_1.STELLATE_PLUGIN_OPTIONS)),
    (0, tslib_1.__metadata)("design:paramtypes", [Object, core_2.EventBus,
        stellate_service_1.StellateService,
        core_1.ModuleRef])
], StellatePlugin);
exports.StellatePlugin = StellatePlugin;
//# sourceMappingURL=stellate-plugin.js.map